.. GROS documentation master file, created by
   sphinx-quickstart on Thu Sep 14 12:42:24 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to GROS's documentation!
================================

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   src.gros_client
   src.gros_client.robot
   src.gros_client.common
